# Generated by Django 3.2.5 on 2022-02-06 14:38

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('xj_user', '0007_merge_20220205_1325'),
    ]

    operations = [
        migrations.AlterField(
            model_name='auth',
            name='password',
            field=models.CharField(blank=True, max_length=255, null=True, verbose_name='密码'),
        ),
        migrations.AlterField(
            model_name='auth',
            name='plaintext',
            field=models.CharField(blank=True, max_length=255, null=True, verbose_name='PT'),
        ),
        migrations.AlterField(
            model_name='auth',
            name='ticket',
            field=models.CharField(blank=True, max_length=255, null=True, verbose_name='临时票据'),
        ),
        migrations.AlterField(
            model_name='auth',
            name='token',
            field=models.CharField(blank=True, max_length=255, null=True, verbose_name='临时凭证'),
        ),
    ]



# Generated by Django 3.2.6 on 2022-01-06 16:17

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('xj_user', '0004_auto_20220101_1707'),
    ]

    operations = [
        migrations.CreateModel(
            name='Auth',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('password', models.CharField(blank=True, max_length=256, null=True, verbose_name='密码')),
                ('plaintext', models.CharField(blank=True, max_length=256, null=True, verbose_name='PT')),
                ('token', models.CharField(blank=True, max_length=256, null=True, verbose_name='临时凭证')),
                ('ticket', models.CharField(blank=True, max_length=256, null=True, verbose_name='临时票据')),
                ('create_time', models.DateTimeField(auto_now_add=True, verbose_name='密码创建时间')),
                ('update_time', models.DateTimeField(auto_now=True, null=True, verbose_name='凭证更新时间')),
                ('xj_user', models.ForeignKey(on_delete=django.db.models.deletion.DO_NOTHING, to='xj_user.baseinfo', verbose_name='用户')),
            ],
            options={
                'verbose_name_plural': '用户安全认证',
                'db_table': 'user_auth',
            },
        ),
    ]
